==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency.md <==
# AwsIoTThingMedicalEmergency


```text
aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency')
```



| Illustration | AwsIoTThingMedicalEmergency | AwsIoTThingMedicalEmergencyCard | AwsIoTThingMedicalEmergencyGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency.png) | ![illustration for AwsIoTThingMedicalEmergency](../../../aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency.Local.png) | ![illustration for AwsIoTThingMedicalEmergencyCard](../../../aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergencyCard.Local.png) | ![illustration for AwsIoTThingMedicalEmergencyGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergencyGroup.Local.png) |




## AwsIoTThingMedicalEmergency

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergency
include('aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergency('AwsIoTThingMedicalEmergency', 'Aws Io T Thing Medical Emergency', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergency
include('aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergency('AwsIoTThingMedicalEmergency', 'Aws Io T Thing Medical Emergency', 'an optional tech label')
@enduml
```

## AwsIoTThingMedicalEmergencyCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergencyCard
include('aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergencyCard('AwsIoTThingMedicalEmergencyCard', 'Aws Io T Thing Medical Emergency Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergencyCard
include('aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergencyCard('AwsIoTThingMedicalEmergencyCard', 'Aws Io T Thing Medical Emergency Card', 'an optional description')
@enduml
```

## AwsIoTThingMedicalEmergencyGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergencyGroup
include('aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergencyGroup('AwsIoTThingMedicalEmergencyGroup', 'Aws Io T Thing Medical Emergency Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergencyGroup
include('aws-q3-2021/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergencyGroup('AwsIoTThingMedicalEmergencyGroup', 'Aws Io T Thing Medical Emergency Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency.md <==
# AwsIoTThingMedicalEmergency


```text
aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency
```

```text
include('aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency')
```



| Illustration | AwsIoTThingMedicalEmergency | AwsIoTThingMedicalEmergencyCard | AwsIoTThingMedicalEmergencyGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency.png) | ![illustration for AwsIoTThingMedicalEmergency](../../../aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency.Local.png) | ![illustration for AwsIoTThingMedicalEmergencyCard](../../../aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergencyCard.Local.png) | ![illustration for AwsIoTThingMedicalEmergencyGroup](../../../aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergencyGroup.Local.png) |




## AwsIoTThingMedicalEmergency

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergency
include('aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergency('AwsIoTThingMedicalEmergency', 'Aws Io T Thing Medical Emergency', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergency
include('aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergency('AwsIoTThingMedicalEmergency', 'Aws Io T Thing Medical Emergency', 'an optional tech label')
@enduml
```

## AwsIoTThingMedicalEmergencyCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergencyCard
include('aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergencyCard('AwsIoTThingMedicalEmergencyCard', 'Aws Io T Thing Medical Emergency Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergencyCard
include('aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergencyCard('AwsIoTThingMedicalEmergencyCard', 'Aws Io T Thing Medical Emergency Card', 'an optional description')
@enduml
```

## AwsIoTThingMedicalEmergencyGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergencyGroup
include('aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergencyGroup('AwsIoTThingMedicalEmergencyGroup', 'Aws Io T Thing Medical Emergency Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingMedicalEmergencyGroup
include('aws-q1-2022/Resource/LoT/AwsIoTThingMedicalEmergency')

' renders the element
AwsIoTThingMedicalEmergencyGroup('AwsIoTThingMedicalEmergencyGroup', 'Aws Io T Thing Medical Emergency Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
